@@ -370,11 +370,13 @@ class StecMultiverseOPCUA(QDialog):
         itm4.setText(str(freq))
 
 
-        bxt1 = QCheckBox( str(enabled))
+       # bxt1 = QCheckBox( str(enabled))
+        bxt1 = QCheckBox("")
         if str(enabled).upper() == "TRUE" :
             bxt1.setChecked(True)
 
-        bxt2 =  QCheckBox(str(readonly))
+        #bxt2 =  QCheckBox(str(readonly))
+        bxt2 = QCheckBox("")
         if str(readonly).upper() == "TRUE":
             bxt2.setChecked(True)
 
@@ -554,7 +556,7 @@ if __name__ == "__main__":
     bumped version
     """
     if "--version" in sys.argv:
-        print("1.2.3")
+        print("1.6.3")
         sys.exit()
 
     show = True
