@@ -1,5 +1,8 @@
-from PyQt5.QtCore import QTimer, QObject, pyqtSignal, pyqtSlot, QSettings
-from stdcom import *
+from PyQt5.QtCore import QTimer, QObject, pyqtSignal, pyqtSlot, QSettings, QDataStream, QByteArray, QVariant, QIODevice, Qt
+from PyQt5.QtWidgets import  QTabWidget, QTableWidgetItem
+
+
+from stdcom import stdcom
 
 """
     This is where Stec QObject are kept, this are not QWidgets
@@ -15,6 +18,103 @@ class VSettings(QSettings):
         super().__init__( project, QSettings.IniFormat)
 
 
+
+
+
+
+
+
+class stdTableSave( ) :
+    project = None
+    def __init__(self, project: str = "stec-opcua"):
+        self.project = project
+
+    def saveTable(self, tableName: str = None, table: QTabWidget = None):
+
+        ba = QByteArray();
+
+        r = table.rowCount()
+        c = table.columnCount()
+
+        stream = QDataStream(ba,QIODevice.WriteOnly)
+        stream.writeInt(c)
+        stream.writeInt(r)
+
+        for row in range(r):
+            for col in range(c):
+                itm = table.item(row, col)
+                if itm is not None:
+                    text = itm.text()
+
+                    try:
+                        data = itm.data()
+
+                    except :
+                        data = []
+                        data.append(QVariant(""))
+
+                    cc = int(col)
+                    rr = int(row)
+                    stream.writeInt(cc)
+                    stream.writeInt(rr)
+                    stream.writeQString(text)
+                    stream.writeQVariant(data)
+
+        settings = VSettings(self.project)
+        settings.setValue(tableName, ba)
+
+    def loadTable(self, tableName: str = None, table: QTabWidget = None):
+
+        ba = QByteArray();
+        settings = VSettings(self.project)
+        ba = settings.value(tableName, ba)
+
+        if ba is None :
+            return
+
+        stream = QDataStream(ba,QIODevice.ReadOnly)
+        c = int(0)
+        r = int(0)
+
+        if stream.atEnd() :
+            return
+        c = stream.readInt()
+
+        if stream.atEnd() :
+            return
+        r = stream.readInt()
+
+        table.setRowCount(int(r))
+        table.setColumnCount(int(c))
+
+        while not stream.atEnd():
+
+            cc = stream.readInt()
+            rr = stream.readInt()
+            itm = table.item(rr, cc)
+
+            if itm is None:
+                itm = QTableWidgetItem()
+
+            text = stream.readQString()
+            itm.setText(text)
+
+            try:
+                data = QVariant(stream.readQVariant())
+                type = data.type()
+
+                if data.isValid() or type == QVariant.List:
+                    itm.setData(Qt.UserRole, data)
+                    table.setItem(rr, cc, itm)
+                else:
+                    print("Unknown Type")
+
+            except:
+                print("Goofy Col ", cc, " : Row ", rr)
+
+
+
+
 class stdcomPyQt(QObject):
     """
     The stdcomPyQt class is a PyQt5 version that sits on top of stdcom, can has signals, slots, and auto restart capabilities build into it.
@@ -43,7 +143,7 @@ class stdcomPyQt(QObject):
     liveOurDesc = {}
 
     timer = None
-    MultiverseHostname = "192.168.199.245"
+    MultiverseHostname = "localhost"
     MultiversePort = 4897
 
     def __init__(self, uiparent: QObject = None):
@@ -316,7 +416,7 @@ if __name__ == "__main__":
     import sys
 
     if "--version" in sys.argv:
-        print("1.5.00")
+        print("1.6.02")
         sys.exit()
 
     app = QCoreApplication(sys.argv)
@@ -324,6 +424,8 @@ if __name__ == "__main__":
     client = stdcomClientPyQt(w)
     w.LoadcBridge()
 
+    w.subscribe("Bang.Bang.Bang")
+    w.writeValues("Bang.Bang.Bang",[1,2,3,4])
 
     app.exec_()
     w.terminate()
