@@ -134,6 +134,7 @@ class stdcomqt5qtree(QTreeWidget):
         v = str(text)
         self.ui.lineEditInput.setText(v)
 
+
     @pyqtSlot(str)
     def AddName(self, name: str):
         """
@@ -221,6 +222,8 @@ class stdcomqt5qtree(QTreeWidget):
 class stdcomqt5qtreeMorph(QWidget):
     """
     Used to create a communication tree of names based on NextStep names
+    It is passed with an exisiting QTreeWidget, this is the most userful of the tree widget because
+    it uses exisitng QTreeWidgets
     """
     newTextSignal = pyqtSignal(str,str)
 
@@ -284,12 +287,18 @@ class stdcomqt5qtreeMorph(QWidget):
 
 
     def clear(self):
+        """
+        clears the list, and puts the original back
+        """
         self.ui.clear()
         self.KeyMap.clear()
         self.descriptions.clear()
         self.AddNames(self.originalList)
 
     def getData(self, item : QTreeWidgetItem):
+        """
+        gets
+        """
         if self.callbackgetdata is not None :
             item.setData(0,Qt.UserRole, self.callbackgetdata(item.text()))
 
@@ -371,6 +380,18 @@ class stdcomqt5qtreeMorph(QWidget):
                 self.newTextSignal.emit(text, desc)
 
 
+    def DeleteSelected(self):
+        """
+        deletes selected items
+        """
+        for ix in self.ui.selectedItems() :
+            type = ix.type()
+            if type == 10001:
+                pp = ix.parent()
+                if pp is not None:
+                    pp.removeChild(ix)
+                    del ix
+
 
 
 
